{% extends "staff/base.html" %}

{% block content %}

<section class="border-red-500">
    <form method="post">
        {{ csrf_input }}
        <div class="p-4">
            <p>Are you sure you want to delete this?</p>
            <button class="px-5 py-2 mt-6 text-white bg-red-600 rounded hover:bg-red-700" type="submit">
                Delete
            </button>
        </div>
    </form>
</section>

{% endblock %}
