/*
These standard CSS rules are intended to make it easier for the
end-user to drop in HTML elements and have a decent, consistent starting point.
 */
table {
    width: 100%;
    font-size: .875rem;
    line-height: 1.25rem;
    table-layout: auto;
}

th {
    text-align: left;
    padding: 0 0.5rem;
    color: rgb(55, 65, 81);
}

table th a {
    color: rgb(55, 65, 81);
}

tbody tr:hover {
    background-color: rgb(249, 250, 251);
}

td {
    padding: 0.5rem 0.5rem;
    white-space: nowrap;
    border-bottom: 1px solid rgb(229, 231, 235);
}
tr:last-child td {
    border-bottom: none;
}

table img {
    height: 1.2rem;
    border-radius: 2px;
}

main a {
    color: rgb(37, 99, 235);
}

main a:hover {
    text-decoration: underline;
}

.actions a, .actions button {
    display: inline-block;
    padding: 8px 16px;
    font-size: 14px;
    font-weight: 500;
    color: #ffffff;
    text-align: center;
    text-decoration: none;
    background-color: #1A1817;
    border: 1px solid #3f3d3b;
    border-radius: 6px;
    transition: background-color 0.2s, border-color 0.2s, transform 0.2s;
    cursor: pointer;

    &:hover {
        background-color: #2a2928;
        border-color: #504e4c;
        transform: translateY(-1px);
    }

    &:active {
        background-color: #141312;
        border-color: #3f3d3b;
        transform: translateY(0);
    }

    &:focus {
        outline: 2px solid #e5e7eb;
        outline-offset: 2px;
    }
}

section {
    border: rgba(0, 0, 0, 0.2) 1px solid;
    border-radius: 0.275rem;
    overflow: auto;
    background-color: white;
    display: flex;
    flex-direction: column;
}

section > header {
    padding: 0.5rem;
    /* background-color: #FFFCF0; */
    border-bottom: rgba(0, 0, 0, 0.2) 1px solid;
}

section > div {
    padding: 0.5rem;
    flex-grow: 1;
    display: flex;
    flex-direction: column;
    align-items: center;
    justify-content: center;
    overflow: auto;
}

section > footer {
    padding: 0.5rem;
    /* background-color: #FFFCF0; */
    border-top: rgba(0, 0, 0, 0.2) 1px solid;
}

#admin-content {
    background-color: #fefdfb;
}
