<div>
    <div class="flex items-center space-x-2">
        <staff.Checkbox field=field />
        <staff.Label field=field>{{ label }}</staff.Label>
    </div>
    <staff.FieldErrors field=field />
</div>
